# JupyterHealth client

A Python client library for the JupyterHealth exchange.

Install:

```
pip install jupyterhealth-client
```

Use:

```python
from jupyterhealth_client import JupyterHealthClient

client = JupyterHealthClient()
```

For more information, see [examples](https://jupyterhealth.org/software-documentation/)
